==> lxqt-panel-0.14.0.tar.xz: lxqt-panel-0.14.0/plugin-taskbar/translations/taskbar_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="648"/>
        <source>Activate task %1</source>
        <translation>Activa la tasca %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="513"/>
        <source>Application</source>
        <translation>Aplicació</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="547"/>
        <source>To &amp;Desktop</source>
        <translation>A l&apos;&amp;escriptori</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="549"/>
        <source>&amp;All Desktops</source>
        <translation>T&amp;ots els escriptoris</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="557"/>
        <source>Desktop &amp;%1</source>
        <translation>Escriptori &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="564"/>
        <source>&amp;To Current Desktop</source>
        <translation>A l&apos;escriptori ac&amp;tual</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="572"/>
        <source>&amp;Move</source>
        <translation>&amp;Mou</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="575"/>
        <source>Resi&amp;ze</source>
        <translation>Redimen&amp;siona</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="582"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximitza</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="589"/>
        <source>Maximize vertically</source>
        <translation>Maximitza verticalment</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="594"/>
        <source>Maximize horizontally</source>
        <translation>Maximitza horitzontalment</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="600"/>
        <source>&amp;Restore</source>
        <translation>&amp;Restaura</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="604"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimitza</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="610"/>
        <source>Roll down</source>
        <translation>Enrotlla cap avall</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="616"/>
        <source>Roll up</source>
        <translation>Enrotlla cap amunt</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="624"/>
        <source>&amp;Layer</source>
        <translation>&amp;Capa</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="626"/>
        <source>Always on &amp;top</source>
        <translation>Sempre a la par&amp;t superior</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="632"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="638"/>
        <source>Always on &amp;bottom</source>
        <translation>Sempre a la part in&amp;ferior</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="646"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="82"/>
        <source>Group</source>
        <translation>Grup</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Close group</source>
        <translation>Tanca el grup</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Ajusts del gestor de tasques</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Mostra únicament les finestres de l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Mostra únicament les finestres de la pantalla del &amp;tauler</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Mostra únicament les finestres minimitzades</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Eleva les finestres minimitzades en l&apos;escriptori actual</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Tanca amb el clic del botó del mig</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="83"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Recorre les finestres amb el desplaçament del ratolí</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="93"/>
        <source>Window &amp;grouping</source>
        <translation>A&amp;grupació de les finestres</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="102"/>
        <source>Show popup on mouse hover</source>
        <translation>Mostra el menú emergent en passar per sobre el ratolí</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Appearance</source>
        <translation>Aparença</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="121"/>
        <source>Button style</source>
        <translation>Estil del botó</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="131"/>
        <source>Maximum button width</source>
        <translation>Amplada màxima del botó</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="144"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="170"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="157"/>
        <source>Maximum button height</source>
        <translation>Alçada màxima del botó</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="183"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Gi&amp;ra automàticament els botons quan el tauler sigui vertical</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="190"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Utilitza les icones de classe de finestra, si estigués disponible</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Icona i text</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Només la icona</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Només el text</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Current</source>
        <translation>Actual</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.15.0.orig.tar.xz: lxqt-panel-0.15.0/plugin-taskbar/translations/taskbar_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="650"/>
        <source>Activate task %1</source>
        <translation>Activa la tasca %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="576"/>
        <source>Application</source>
        <translation>Aplicació</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="610"/>
        <source>To &amp;Desktop</source>
        <translation>A l&apos;&amp;escriptori</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="612"/>
        <source>&amp;All Desktops</source>
        <translation>T&amp;ots els escriptoris</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="620"/>
        <source>Desktop &amp;%1</source>
        <translation>Escriptori &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="627"/>
        <source>&amp;To Current Desktop</source>
        <translation>A l&apos;escriptori ac&amp;tual</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="635"/>
        <source>&amp;Move</source>
        <translation>&amp;Mou</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="638"/>
        <source>Resi&amp;ze</source>
        <translation>Redimen&amp;siona</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="645"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximitza</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="652"/>
        <source>Maximize vertically</source>
        <translation>Maximitza verticalment</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="657"/>
        <source>Maximize horizontally</source>
        <translation>Maximitza horitzontalment</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="663"/>
        <source>&amp;Restore</source>
        <translation>&amp;Restaura</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="667"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimitza</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="673"/>
        <source>Roll down</source>
        <translation>Enrotlla cap avall</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="679"/>
        <source>Roll up</source>
        <translation>Enrotlla cap amunt</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="687"/>
        <source>&amp;Layer</source>
        <translation>&amp;Capa</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="689"/>
        <source>Always on &amp;top</source>
        <translation>Sempre a la par&amp;t superior</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="695"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="701"/>
        <source>Always on &amp;bottom</source>
        <translation>Sempre a la part in&amp;ferior</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="709"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="82"/>
        <source>Group</source>
        <translation>Grup</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Close group</source>
        <translation>Tanca el grup</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Ajusts del gestor de tasques</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Mostra únicament les finestres de l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Mostra únicament les finestres de la pantalla del &amp;tauler</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Mostra únicament les finestres minimitzades</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Eleva les finestres minimitzades en l&apos;escriptori actual</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Tanca amb el clic del botó del mig</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Recorre les finestres amb el desplaçament del ratolí</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>A&amp;grupació de les finestres</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Mostra el menú emergent en passar per sobre el ratolí</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Appearance</source>
        <translation>Aparença</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="171"/>
        <source>Button style</source>
        <translation>Estil del botó</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="181"/>
        <source>Maximum button width</source>
        <translation>Amplada màxima del botó</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="194"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="220"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="207"/>
        <source>Maximum button height</source>
        <translation>Alçada màxima del botó</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="233"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Gi&amp;ra automàticament els botons quan el tauler sigui vertical</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Utilitza les icones de classe de finestra, si estigués disponible</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Icona i text</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Només la icona</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Només el text</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Current</source>
        <translation>Actual</translation>
    </message>
</context>
</TS>
